"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NotebooksEnvironmentXContainerImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksEnvironmentXContainerImage = NotebooksEnvironmentXContainerImage

@typing_extensions.final
class NotebooksEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksEnvironmentXTimeouts = NotebooksEnvironmentXTimeouts

@typing_extensions.final
class NotebooksEnvironmentXVmImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FAMILY_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    image_family: builtins.str
    image_name: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        image_family: builtins.str = ...,
        image_name: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_family", b"image_family", "image_name", b"image_name", "project", b"project"]) -> None: ...

global___NotebooksEnvironmentXVmImage = NotebooksEnvironmentXVmImage

@typing_extensions.final
class NotebooksEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VM_IMAGE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    display_name: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    post_startup_script: builtins.str
    project: builtins.str
    @property
    def container_image(self) -> global___NotebooksEnvironmentXContainerImage: ...
    @property
    def timeouts(self) -> global___NotebooksEnvironmentXTimeouts: ...
    @property
    def vm_image(self) -> global___NotebooksEnvironmentXVmImage: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        post_startup_script: builtins.str = ...,
        project: builtins.str = ...,
        container_image: global___NotebooksEnvironmentXContainerImage | None = ...,
        timeouts: global___NotebooksEnvironmentXTimeouts | None = ...,
        vm_image: global___NotebooksEnvironmentXVmImage | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_image", b"container_image", "resource_info", b"resource_info", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_image", b"container_image", "create_time", b"create_time", "description", b"description", "display_name", b"display_name", "id", b"id", "location", b"location", "name", b"name", "post_startup_script", b"post_startup_script", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> None: ...

global___NotebooksEnvironment = NotebooksEnvironment

@typing_extensions.final
class NotebooksInstanceXAcceleratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    core_count: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        core_count: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "type", b"type"]) -> None: ...

global___NotebooksInstanceXAcceleratorConfig = NotebooksInstanceXAcceleratorConfig

@typing_extensions.final
class NotebooksInstanceXContainerImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksInstanceXContainerImage = NotebooksInstanceXContainerImage

@typing_extensions.final
class NotebooksInstanceXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUME_RESERVATION_TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    consume_reservation_type: builtins.str
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        consume_reservation_type: builtins.str = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consume_reservation_type", b"consume_reservation_type", "key", b"key", "values", b"values"]) -> None: ...

global___NotebooksInstanceXReservationAffinity = NotebooksInstanceXReservationAffinity

@typing_extensions.final
class NotebooksInstanceXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___NotebooksInstanceXShieldedInstanceConfig = NotebooksInstanceXShieldedInstanceConfig

@typing_extensions.final
class NotebooksInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksInstanceXTimeouts = NotebooksInstanceXTimeouts

@typing_extensions.final
class NotebooksInstanceXVmImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FAMILY_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    image_family: builtins.str
    image_name: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        image_family: builtins.str = ...,
        image_name: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_family", b"image_family", "image_name", b"image_name", "project", b"project"]) -> None: ...

global___NotebooksInstanceXVmImage = NotebooksInstanceXVmImage

@typing_extensions.final
class NotebooksInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    CUSTOM_GPU_DRIVER_PATH_FIELD_NUMBER: builtins.int
    DATA_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DATA_DISK_TYPE_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTALL_GPU_DRIVER_FIELD_NUMBER: builtins.int
    INSTANCE_OWNERS_FIELD_NUMBER: builtins.int
    KMS_KEY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    NO_PROXY_ACCESS_FIELD_NUMBER: builtins.int
    NO_PUBLIC_IP_FIELD_NUMBER: builtins.int
    NO_REMOVE_DATA_DISK_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROXY_URI_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_SCOPES_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ACCELERATOR_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGE_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VM_IMAGE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    create_time: builtins.str
    custom_gpu_driver_path: builtins.str
    data_disk_size_gb: builtins.float
    data_disk_type: builtins.str
    disk_encryption: builtins.str
    id: builtins.str
    install_gpu_driver: builtins.bool
    @property
    def instance_owners(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    kms_key: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    network: builtins.str
    nic_type: builtins.str
    no_proxy_access: builtins.bool
    no_public_ip: builtins.bool
    no_remove_data_disk: builtins.bool
    post_startup_script: builtins.str
    project: builtins.str
    proxy_uri: builtins.str
    service_account: builtins.str
    @property
    def service_account_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    state: builtins.str
    subnet: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    update_time: builtins.str
    @property
    def accelerator_config(self) -> global___NotebooksInstanceXAcceleratorConfig: ...
    @property
    def container_image(self) -> global___NotebooksInstanceXContainerImage: ...
    @property
    def reservation_affinity(self) -> global___NotebooksInstanceXReservationAffinity: ...
    @property
    def shielded_instance_config(self) -> global___NotebooksInstanceXShieldedInstanceConfig: ...
    @property
    def timeouts(self) -> global___NotebooksInstanceXTimeouts: ...
    @property
    def vm_image(self) -> global___NotebooksInstanceXVmImage: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        create_time: builtins.str = ...,
        custom_gpu_driver_path: builtins.str = ...,
        data_disk_size_gb: builtins.float = ...,
        data_disk_type: builtins.str = ...,
        disk_encryption: builtins.str = ...,
        id: builtins.str = ...,
        install_gpu_driver: builtins.bool = ...,
        instance_owners: collections.abc.Iterable[builtins.str] | None = ...,
        kms_key: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        nic_type: builtins.str = ...,
        no_proxy_access: builtins.bool = ...,
        no_public_ip: builtins.bool = ...,
        no_remove_data_disk: builtins.bool = ...,
        post_startup_script: builtins.str = ...,
        project: builtins.str = ...,
        proxy_uri: builtins.str = ...,
        service_account: builtins.str = ...,
        service_account_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        state: builtins.str = ...,
        subnet: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        update_time: builtins.str = ...,
        accelerator_config: global___NotebooksInstanceXAcceleratorConfig | None = ...,
        container_image: global___NotebooksInstanceXContainerImage | None = ...,
        reservation_affinity: global___NotebooksInstanceXReservationAffinity | None = ...,
        shielded_instance_config: global___NotebooksInstanceXShieldedInstanceConfig | None = ...,
        timeouts: global___NotebooksInstanceXTimeouts | None = ...,
        vm_image: global___NotebooksInstanceXVmImage | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "container_image", b"container_image", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "shielded_instance_config", b"shielded_instance_config", "timeouts", b"timeouts", "vm_image", b"vm_image"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "container_image", b"container_image", "create_time", b"create_time", "custom_gpu_driver_path", b"custom_gpu_driver_path", "data_disk_size_gb", b"data_disk_size_gb", "data_disk_type", b"data_disk_type", "disk_encryption", b"disk_encryption", "id", b"id", "install_gpu_driver", b"install_gpu_driver", "instance_owners", b"instance_owners", "kms_key", b"kms_key", "labels", b"labels", "location", b"location", "machine_type", b"machine_type", "metadata", b"metadata", "name", b"name", "network", b"network", "nic_type", b"nic_type", "no_proxy_access", b"no_proxy_access", "no_public_ip", b"no_public_ip", "no_remove_data_disk", b"no_remove_data_disk", "post_startup_script", b"post_startup_script", "project", b"project", "proxy_uri", b"proxy_uri", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "service_account", b"service_account", "service_account_scopes", b"service_account_scopes", "shielded_instance_config", b"shielded_instance_config", "state", b"state", "subnet", b"subnet", "tags", b"tags", "timeouts", b"timeouts", "update_time", b"update_time", "vm_image", b"vm_image"]) -> None: ...

global___NotebooksInstance = NotebooksInstance

@typing_extensions.final
class NotebooksInstanceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksInstanceIamBindingXCondition = NotebooksInstanceIamBindingXCondition

@typing_extensions.final
class NotebooksInstanceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___NotebooksInstanceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___NotebooksInstanceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___NotebooksInstanceIamBinding = NotebooksInstanceIamBinding

@typing_extensions.final
class NotebooksInstanceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksInstanceIamMemberXCondition = NotebooksInstanceIamMemberXCondition

@typing_extensions.final
class NotebooksInstanceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___NotebooksInstanceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___NotebooksInstanceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___NotebooksInstanceIamMember = NotebooksInstanceIamMember

@typing_extensions.final
class NotebooksInstanceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance_name", b"instance_name", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___NotebooksInstanceIamPolicy = NotebooksInstanceIamPolicy

@typing_extensions.final
class NotebooksLocationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksLocationXTimeouts = NotebooksLocationXTimeouts

@typing_extensions.final
class NotebooksLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___NotebooksLocationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___NotebooksLocationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___NotebooksLocation = NotebooksLocation

@typing_extensions.final
class NotebooksRuntimeXAccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TYPE_FIELD_NUMBER: builtins.int
    PROXY_URI_FIELD_NUMBER: builtins.int
    RUNTIME_OWNER_FIELD_NUMBER: builtins.int
    access_type: builtins.str
    proxy_uri: builtins.str
    runtime_owner: builtins.str
    def __init__(
        self,
        *,
        access_type: builtins.str = ...,
        proxy_uri: builtins.str = ...,
        runtime_owner: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_type", b"access_type", "proxy_uri", b"proxy_uri", "runtime_owner", b"runtime_owner"]) -> None: ...

global___NotebooksRuntimeXAccessConfig = NotebooksRuntimeXAccessConfig

@typing_extensions.final
class NotebooksRuntimeXSoftwareConfigXKernels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksRuntimeXSoftwareConfigXKernels = NotebooksRuntimeXSoftwareConfigXKernels

@typing_extensions.final
class NotebooksRuntimeXSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_GPU_DRIVER_PATH_FIELD_NUMBER: builtins.int
    ENABLE_HEALTH_MONITORING_FIELD_NUMBER: builtins.int
    IDLE_SHUTDOWN_FIELD_NUMBER: builtins.int
    IDLE_SHUTDOWN_TIMEOUT_FIELD_NUMBER: builtins.int
    INSTALL_GPU_DRIVER_FIELD_NUMBER: builtins.int
    NOTEBOOK_UPGRADE_SCHEDULE_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    POST_STARTUP_SCRIPT_BEHAVIOR_FIELD_NUMBER: builtins.int
    UPGRADEABLE_FIELD_NUMBER: builtins.int
    KERNELS_FIELD_NUMBER: builtins.int
    custom_gpu_driver_path: builtins.str
    enable_health_monitoring: builtins.bool
    idle_shutdown: builtins.bool
    idle_shutdown_timeout: builtins.float
    install_gpu_driver: builtins.bool
    notebook_upgrade_schedule: builtins.str
    post_startup_script: builtins.str
    post_startup_script_behavior: builtins.str
    upgradeable: builtins.bool
    @property
    def kernels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebooksRuntimeXSoftwareConfigXKernels]: ...
    def __init__(
        self,
        *,
        custom_gpu_driver_path: builtins.str = ...,
        enable_health_monitoring: builtins.bool = ...,
        idle_shutdown: builtins.bool = ...,
        idle_shutdown_timeout: builtins.float = ...,
        install_gpu_driver: builtins.bool = ...,
        notebook_upgrade_schedule: builtins.str = ...,
        post_startup_script: builtins.str = ...,
        post_startup_script_behavior: builtins.str = ...,
        upgradeable: builtins.bool = ...,
        kernels: collections.abc.Iterable[global___NotebooksRuntimeXSoftwareConfigXKernels] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_gpu_driver_path", b"custom_gpu_driver_path", "enable_health_monitoring", b"enable_health_monitoring", "idle_shutdown", b"idle_shutdown", "idle_shutdown_timeout", b"idle_shutdown_timeout", "install_gpu_driver", b"install_gpu_driver", "kernels", b"kernels", "notebook_upgrade_schedule", b"notebook_upgrade_schedule", "post_startup_script", b"post_startup_script", "post_startup_script_behavior", b"post_startup_script_behavior", "upgradeable", b"upgradeable"]) -> None: ...

global___NotebooksRuntimeXSoftwareConfig = NotebooksRuntimeXSoftwareConfig

@typing_extensions.final
class NotebooksRuntimeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NotebooksRuntimeXTimeouts = NotebooksRuntimeXTimeouts

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    core_count: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        core_count: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "type", b"type"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    repository: builtins.str
    tag: builtins.str
    def __init__(
        self,
        *,
        repository: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository", "tag", b"tag"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_NAME_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    description: builtins.str
    disk_name: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disk_name: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disk_name", b"disk_name", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "labels", b"labels"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_FIELD_NUMBER: builtins.int
    BOOT_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    GUEST_OS_FEATURES_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    INITIALIZE_PARAMS_FIELD_NUMBER: builtins.int
    auto_delete: builtins.bool
    boot: builtins.bool
    device_name: builtins.str
    @property
    def guest_os_features(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    index: builtins.float
    interface: builtins.str
    kind: builtins.str
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    mode: builtins.str
    source: builtins.str
    type: builtins.str
    @property
    def initialize_params(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams: ...
    def __init__(
        self,
        *,
        auto_delete: builtins.bool = ...,
        boot: builtins.bool = ...,
        device_name: builtins.str = ...,
        guest_os_features: collections.abc.Iterable[builtins.str] | None = ...,
        index: builtins.float = ...,
        interface: builtins.str = ...,
        kind: builtins.str = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
        type: builtins.str = ...,
        initialize_params: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initialize_params", b"initialize_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete", b"auto_delete", "boot", b"boot", "device_name", b"device_name", "guest_os_features", b"guest_os_features", "index", b"index", "initialize_params", b"initialize_params", "interface", b"interface", "kind", b"kind", "licenses", b"licenses", "mode", b"mode", "source", b"source", "type", b"type"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_FIELD_NUMBER: builtins.int
    kms_key: builtins.str
    def __init__(
        self,
        *,
        kms_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key", b"kms_key"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachineXVirtualMachineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    GUEST_ATTRIBUTES_FIELD_NUMBER: builtins.int
    INTERNAL_IP_ONLY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    ACCELERATOR_CONFIG_FIELD_NUMBER: builtins.int
    CONTAINER_IMAGES_FIELD_NUMBER: builtins.int
    DATA_DISK_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def guest_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    internal_ip_only: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    network: builtins.str
    nic_type: builtins.str
    reserved_ip_range: builtins.str
    subnet: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def accelerator_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig: ...
    @property
    def container_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages]: ...
    @property
    def data_disk(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk: ...
    @property
    def encryption_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig: ...
    @property
    def shielded_instance_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig: ...
    def __init__(
        self,
        *,
        guest_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        internal_ip_only: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network: builtins.str = ...,
        nic_type: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
        subnet: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        accelerator_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig | None = ...,
        container_images: collections.abc.Iterable[global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages] | None = ...,
        data_disk: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk | None = ...,
        encryption_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig | None = ...,
        shielded_instance_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "data_disk", b"data_disk", "encryption_config", b"encryption_config", "shielded_instance_config", b"shielded_instance_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_config", b"accelerator_config", "container_images", b"container_images", "data_disk", b"data_disk", "encryption_config", b"encryption_config", "guest_attributes", b"guest_attributes", "internal_ip_only", b"internal_ip_only", "labels", b"labels", "machine_type", b"machine_type", "metadata", b"metadata", "network", b"network", "nic_type", b"nic_type", "reserved_ip_range", b"reserved_ip_range", "shielded_instance_config", b"shielded_instance_config", "subnet", b"subnet", "tags", b"tags", "zone", b"zone"]) -> None: ...

global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig = NotebooksRuntimeXVirtualMachineXVirtualMachineConfig

@typing_extensions.final
class NotebooksRuntimeXVirtualMachine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_CONFIG_FIELD_NUMBER: builtins.int
    instance_id: builtins.str
    instance_name: builtins.str
    @property
    def virtual_machine_config(self) -> global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig: ...
    def __init__(
        self,
        *,
        instance_id: builtins.str = ...,
        instance_name: builtins.str = ...,
        virtual_machine_config: global___NotebooksRuntimeXVirtualMachineXVirtualMachineConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["virtual_machine_config", b"virtual_machine_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_id", b"instance_id", "instance_name", b"instance_name", "virtual_machine_config", b"virtual_machine_config"]) -> None: ...

global___NotebooksRuntimeXVirtualMachine = NotebooksRuntimeXVirtualMachine

@typing_extensions.final
class NotebooksRuntime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetricsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    HEALTH_STATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    health_state: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def metrics(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    state: builtins.str
    @property
    def access_config(self) -> global___NotebooksRuntimeXAccessConfig: ...
    @property
    def software_config(self) -> global___NotebooksRuntimeXSoftwareConfig: ...
    @property
    def timeouts(self) -> global___NotebooksRuntimeXTimeouts: ...
    @property
    def virtual_machine(self) -> global___NotebooksRuntimeXVirtualMachine: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        health_state: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        metrics: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        access_config: global___NotebooksRuntimeXAccessConfig | None = ...,
        software_config: global___NotebooksRuntimeXSoftwareConfig | None = ...,
        timeouts: global___NotebooksRuntimeXTimeouts | None = ...,
        virtual_machine: global___NotebooksRuntimeXVirtualMachine | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "resource_info", b"resource_info", "software_config", b"software_config", "timeouts", b"timeouts", "virtual_machine", b"virtual_machine"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "health_state", b"health_state", "id", b"id", "location", b"location", "metrics", b"metrics", "name", b"name", "project", b"project", "resource_info", b"resource_info", "software_config", b"software_config", "state", b"state", "timeouts", b"timeouts", "virtual_machine", b"virtual_machine"]) -> None: ...

global___NotebooksRuntime = NotebooksRuntime

@typing_extensions.final
class NotebooksRuntimeIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksRuntimeIamBindingXCondition = NotebooksRuntimeIamBindingXCondition

@typing_extensions.final
class NotebooksRuntimeIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    runtime_name: builtins.str
    @property
    def condition(self) -> global___NotebooksRuntimeIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        runtime_name: builtins.str = ...,
        condition: global___NotebooksRuntimeIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamBinding = NotebooksRuntimeIamBinding

@typing_extensions.final
class NotebooksRuntimeIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___NotebooksRuntimeIamMemberXCondition = NotebooksRuntimeIamMemberXCondition

@typing_extensions.final
class NotebooksRuntimeIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    runtime_name: builtins.str
    @property
    def condition(self) -> global___NotebooksRuntimeIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        runtime_name: builtins.str = ...,
        condition: global___NotebooksRuntimeIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamMember = NotebooksRuntimeIamMember

@typing_extensions.final
class NotebooksRuntimeIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    runtime_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        runtime_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "runtime_name", b"runtime_name"]) -> None: ...

global___NotebooksRuntimeIamPolicy = NotebooksRuntimeIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AuthorizerTokenSigningPublicKeys(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___AuthorizerTokenSigningPublicKeys = AuthorizerTokenSigningPublicKeys

@typing_extensions.final
class AuthorizerTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___AuthorizerTags = AuthorizerTags

@typing_extensions.final
class Authorizer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTHORIZER_FUNCTION_ARN_FIELD_NUMBER: builtins.int
    AUTHORIZER_NAME_FIELD_NUMBER: builtins.int
    SIGNING_DISABLED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TOKEN_KEY_NAME_FIELD_NUMBER: builtins.int
    TOKEN_SIGNING_PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    authorizer_function_arn: builtins.str
    authorizer_name: builtins.str
    signing_disabled: builtins.bool
    status: builtins.str
    token_key_name: builtins.str
    @property
    def token_signing_public_keys(self) -> global___AuthorizerTokenSigningPublicKeys: ...
    @property
    def tags(self) -> global___AuthorizerTags: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        authorizer_function_arn: builtins.str = ...,
        authorizer_name: builtins.str = ...,
        signing_disabled: builtins.bool = ...,
        status: builtins.str = ...,
        token_key_name: builtins.str = ...,
        token_signing_public_keys: global___AuthorizerTokenSigningPublicKeys | None = ...,
        tags: global___AuthorizerTags | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags", "token_signing_public_keys", b"token_signing_public_keys"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorizer_function_arn", b"authorizer_function_arn", "authorizer_name", b"authorizer_name", "resource_info", b"resource_info", "signing_disabled", b"signing_disabled", "status", b"status", "tags", b"tags", "token_key_name", b"token_key_name", "token_signing_public_keys", b"token_signing_public_keys"]) -> None: ...

global___Authorizer = Authorizer

@typing_extensions.final
class IoT(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZER_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    POLICY_PRINCIPAL_ATTACHMENT_FIELD_NUMBER: builtins.int
    PROVISIONING_TEMPLATE_FIELD_NUMBER: builtins.int
    THING_FIELD_NUMBER: builtins.int
    THING_PRINCIPAL_ATTACHMENT_FIELD_NUMBER: builtins.int
    TOPIC_RULE_FIELD_NUMBER: builtins.int
    @property
    def authorizer(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Authorizer]: ...
    @property
    def certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Certificate]: ...
    @property
    def policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Policy]: ...
    @property
    def policy_principal_attachment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyPrincipalAttachment]: ...
    @property
    def provisioning_template(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProvisioningTemplate]: ...
    @property
    def thing(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Thing]: ...
    @property
    def thing_principal_attachment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThingPrincipalAttachment]: ...
    @property
    def topic_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicRule]: ...
    def __init__(
        self,
        *,
        authorizer: collections.abc.Iterable[global___Authorizer] | None = ...,
        certificate: collections.abc.Iterable[global___Certificate] | None = ...,
        policy: collections.abc.Iterable[global___Policy] | None = ...,
        policy_principal_attachment: collections.abc.Iterable[global___PolicyPrincipalAttachment] | None = ...,
        provisioning_template: collections.abc.Iterable[global___ProvisioningTemplate] | None = ...,
        thing: collections.abc.Iterable[global___Thing] | None = ...,
        thing_principal_attachment: collections.abc.Iterable[global___ThingPrincipalAttachment] | None = ...,
        topic_rule: collections.abc.Iterable[global___TopicRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorizer", b"authorizer", "certificate", b"certificate", "policy", b"policy", "policy_principal_attachment", b"policy_principal_attachment", "provisioning_template", b"provisioning_template", "thing", b"thing", "thing_principal_attachment", b"thing_principal_attachment", "topic_rule", b"topic_rule"]) -> None: ...

global___IoT = IoT

@typing_extensions.final
class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CA_CERTIFICATE_PEM_FIELD_NUMBER: builtins.int
    CERTIFICATE_PEM_FIELD_NUMBER: builtins.int
    CERTIFICATE_SIGNING_REQUEST_FIELD_NUMBER: builtins.int
    CERTIFICATE_MODE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ca_certificate_pem: builtins.str
    certificate_pem: builtins.str
    certificate_signing_request: builtins.str
    certificate_mode: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ca_certificate_pem: builtins.str = ...,
        certificate_pem: builtins.str = ...,
        certificate_signing_request: builtins.str = ...,
        certificate_mode: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_certificate_pem", b"ca_certificate_pem", "certificate_mode", b"certificate_mode", "certificate_pem", b"certificate_pem", "certificate_signing_request", b"certificate_signing_request", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___Certificate = Certificate

@typing_extensions.final
class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PolicyDocumentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_DOCUMENT_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def policy_document(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    policy_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy_document: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        policy_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_document", b"policy_document", "policy_name", b"policy_name", "resource_info", b"resource_info"]) -> None: ...

global___Policy = Policy

@typing_extensions.final
class PolicyPrincipalAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_NAME_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    policy_name: builtins.str
    principal: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy_name: builtins.str = ...,
        principal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_name", b"policy_name", "principal", b"principal", "resource_info", b"resource_info"]) -> None: ...

global___PolicyPrincipalAttachment = PolicyPrincipalAttachment

@typing_extensions.final
class ProvisioningTemplateProvisioningHook(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    PAYLOAD_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_arn: builtins.str
    payload_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_arn: builtins.str = ...,
        payload_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["payload_version", b"payload_version", "resource_info", b"resource_info", "target_arn", b"target_arn"]) -> None: ...

global___ProvisioningTemplateProvisioningHook = ProvisioningTemplateProvisioningHook

@typing_extensions.final
class ProvisioningTemplateTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ProvisioningTemplateTags = ProvisioningTemplateTags

@typing_extensions.final
class ProvisioningTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    PROVISIONING_ROLE_ARN_FIELD_NUMBER: builtins.int
    TEMPLATE_BODY_FIELD_NUMBER: builtins.int
    PRE_PROVISIONING_HOOK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    template_name: builtins.str
    description: builtins.str
    enabled: builtins.bool
    provisioning_role_arn: builtins.str
    template_body: builtins.str
    @property
    def pre_provisioning_hook(self) -> global___ProvisioningTemplateProvisioningHook: ...
    @property
    def tags(self) -> global___ProvisioningTemplateTags: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        template_name: builtins.str = ...,
        description: builtins.str = ...,
        enabled: builtins.bool = ...,
        provisioning_role_arn: builtins.str = ...,
        template_body: builtins.str = ...,
        pre_provisioning_hook: global___ProvisioningTemplateProvisioningHook | None = ...,
        tags: global___ProvisioningTemplateTags | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pre_provisioning_hook", b"pre_provisioning_hook", "resource_info", b"resource_info", "tags", b"tags"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "enabled", b"enabled", "pre_provisioning_hook", b"pre_provisioning_hook", "provisioning_role_arn", b"provisioning_role_arn", "resource_info", b"resource_info", "tags", b"tags", "template_body", b"template_body", "template_name", b"template_name"]) -> None: ...

global___ProvisioningTemplate = ProvisioningTemplate

@typing_extensions.final
class ThingAttributePayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attributes", b"attributes", "resource_info", b"resource_info"]) -> None: ...

global___ThingAttributePayload = ThingAttributePayload

@typing_extensions.final
class Thing(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_PAYLOAD_FIELD_NUMBER: builtins.int
    THING_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def attribute_payload(self) -> global___ThingAttributePayload: ...
    thing_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_payload: global___ThingAttributePayload | None = ...,
        thing_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attribute_payload", b"attribute_payload", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_payload", b"attribute_payload", "resource_info", b"resource_info", "thing_name", b"thing_name"]) -> None: ...

global___Thing = Thing

@typing_extensions.final
class ThingPrincipalAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    THING_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    principal: builtins.str
    thing_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        principal: builtins.str = ...,
        thing_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal", b"principal", "resource_info", b"resource_info", "thing_name", b"thing_name"]) -> None: ...

global___ThingPrincipalAttachment = ThingPrincipalAttachment

@typing_extensions.final
class TopicRuleCloudwatchAlarmAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STATE_REASON_FIELD_NUMBER: builtins.int
    STATE_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    alarm_name: builtins.str
    role_arn: builtins.str
    state_reason: builtins.str
    state_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_name: builtins.str = ...,
        role_arn: builtins.str = ...,
        state_reason: builtins.str = ...,
        state_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_name", b"alarm_name", "resource_info", b"resource_info", "role_arn", b"role_arn", "state_reason", b"state_reason", "state_value", b"state_value"]) -> None: ...

global___TopicRuleCloudwatchAlarmAction = TopicRuleCloudwatchAlarmAction

@typing_extensions.final
class TopicRuleCloudwatchMetricAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_NAMESPACE_FIELD_NUMBER: builtins.int
    METRIC_TIMESTAMP_FIELD_NUMBER: builtins.int
    METRIC_UNIT_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_name: builtins.str
    metric_namespace: builtins.str
    metric_timestamp: builtins.str
    metric_unit: builtins.str
    metric_value: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_name: builtins.str = ...,
        metric_namespace: builtins.str = ...,
        metric_timestamp: builtins.str = ...,
        metric_unit: builtins.str = ...,
        metric_value: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_name", b"metric_name", "metric_namespace", b"metric_namespace", "metric_timestamp", b"metric_timestamp", "metric_unit", b"metric_unit", "metric_value", b"metric_value", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleCloudwatchMetricAction = TopicRuleCloudwatchMetricAction

@typing_extensions.final
class TopicRuleDynamoDBAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HASH_KEY_FIELD_FIELD_NUMBER: builtins.int
    HASH_KEY_TYPE_FIELD_NUMBER: builtins.int
    HASH_KEY_VALUE_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_FIELD_NUMBER: builtins.int
    RANGE_KEY_FIELD_FIELD_NUMBER: builtins.int
    RANGE_KEY_TYPE_FIELD_NUMBER: builtins.int
    RANGE_KEY_VALUE_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    hash_key_field: builtins.str
    hash_key_type: builtins.str
    hash_key_value: builtins.str
    payload_field: builtins.str
    range_key_field: builtins.str
    range_key_type: builtins.str
    range_key_value: builtins.str
    role_arn: builtins.str
    table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hash_key_field: builtins.str = ...,
        hash_key_type: builtins.str = ...,
        hash_key_value: builtins.str = ...,
        payload_field: builtins.str = ...,
        range_key_field: builtins.str = ...,
        range_key_type: builtins.str = ...,
        range_key_value: builtins.str = ...,
        role_arn: builtins.str = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash_key_field", b"hash_key_field", "hash_key_type", b"hash_key_type", "hash_key_value", b"hash_key_value", "payload_field", b"payload_field", "range_key_field", b"range_key_field", "range_key_type", b"range_key_type", "range_key_value", b"range_key_value", "resource_info", b"resource_info", "role_arn", b"role_arn", "table_name", b"table_name"]) -> None: ...

global___TopicRuleDynamoDBAction = TopicRuleDynamoDBAction

@typing_extensions.final
class TopicRulePutItemInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "table_name", b"table_name"]) -> None: ...

global___TopicRulePutItemInput = TopicRulePutItemInput

@typing_extensions.final
class TopicRuleDynamoDBv2Action(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PUT_ITEM_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def put_item(self) -> global___TopicRulePutItemInput: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        put_item: global___TopicRulePutItemInput | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["put_item", b"put_item", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["put_item", b"put_item", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleDynamoDBv2Action = TopicRuleDynamoDBv2Action

@typing_extensions.final
class TopicRuleElasticsearchAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    endpoint: builtins.str
    id: builtins.str
    index: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        endpoint: builtins.str = ...,
        id: builtins.str = ...,
        index: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint", b"endpoint", "id", b"id", "index", b"index", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleElasticsearchAction = TopicRuleElasticsearchAction

@typing_extensions.final
class TopicRuleFirehoseAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SEPARATOR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_stream_name: builtins.str
    role_arn: builtins.str
    separator: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_stream_name: builtins.str = ...,
        role_arn: builtins.str = ...,
        separator: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream_name", b"delivery_stream_name", "resource_info", b"resource_info", "role_arn", b"role_arn", "separator", b"separator"]) -> None: ...

global___TopicRuleFirehoseAction = TopicRuleFirehoseAction

@typing_extensions.final
class TopicRuleSigV4Authorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    SIGNING_REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    role_arn: builtins.str
    service_name: builtins.str
    signing_region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        role_arn: builtins.str = ...,
        service_name: builtins.str = ...,
        signing_region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "role_arn", b"role_arn", "service_name", b"service_name", "signing_region", b"signing_region"]) -> None: ...

global___TopicRuleSigV4Authorization = TopicRuleSigV4Authorization

@typing_extensions.final
class TopicRuleHttpAuthorization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SIGV4_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def sigv4(self) -> global___TopicRuleSigV4Authorization: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        sigv4: global___TopicRuleSigV4Authorization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sigv4", b"sigv4"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sigv4", b"sigv4"]) -> None: ...

global___TopicRuleHttpAuthorization = TopicRuleHttpAuthorization

@typing_extensions.final
class TopicRuleHttpActionHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___TopicRuleHttpActionHeader = TopicRuleHttpActionHeader

@typing_extensions.final
class TopicRuleHttpAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    CONFIRMATION_URL_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def auth(self) -> global___TopicRuleHttpAuthorization: ...
    confirmation_url: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicRuleHttpActionHeader]: ...
    url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth: global___TopicRuleHttpAuthorization | None = ...,
        confirmation_url: builtins.str = ...,
        headers: collections.abc.Iterable[global___TopicRuleHttpActionHeader] | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "confirmation_url", b"confirmation_url", "headers", b"headers", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___TopicRuleHttpAction = TopicRuleHttpAction

@typing_extensions.final
class TopicRuleIotAnalyticsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    channel_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        channel_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_name", b"channel_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleIotAnalyticsAction = TopicRuleIotAnalyticsAction

@typing_extensions.final
class TopicRuleIotEventsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INPUT_NAME_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    input_name: builtins.str
    message_id: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        input_name: builtins.str = ...,
        message_id: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_name", b"input_name", "message_id", b"message_id", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleIotEventsAction = TopicRuleIotEventsAction

@typing_extensions.final
class TopicRuleAssetPropertyTimestamp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OFFSET_IN_NANOS_FIELD_NUMBER: builtins.int
    TIME_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    offset_in_nanos: builtins.str
    time_in_seconds: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        offset_in_nanos: builtins.str = ...,
        time_in_seconds: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["offset_in_nanos", b"offset_in_nanos", "resource_info", b"resource_info", "time_in_seconds", b"time_in_seconds"]) -> None: ...

global___TopicRuleAssetPropertyTimestamp = TopicRuleAssetPropertyTimestamp

@typing_extensions.final
class TopicRuleAssetPropertyVariant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    INTEGER_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    boolean_value: builtins.str
    double_value: builtins.str
    integer_value: builtins.str
    string_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        boolean_value: builtins.str = ...,
        double_value: builtins.str = ...,
        integer_value: builtins.str = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["boolean_value", b"boolean_value", "double_value", b"double_value", "integer_value", b"integer_value", "resource_info", b"resource_info", "string_value", b"string_value"]) -> None: ...

global___TopicRuleAssetPropertyVariant = TopicRuleAssetPropertyVariant

@typing_extensions.final
class TopicRuleAssetPropertyValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    quality: builtins.str
    @property
    def timestamp(self) -> global___TopicRuleAssetPropertyTimestamp: ...
    @property
    def value(self) -> global___TopicRuleAssetPropertyVariant: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        quality: builtins.str = ...,
        timestamp: global___TopicRuleAssetPropertyTimestamp | None = ...,
        value: global___TopicRuleAssetPropertyVariant | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timestamp", b"timestamp", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["quality", b"quality", "resource_info", b"resource_info", "timestamp", b"timestamp", "value", b"value"]) -> None: ...

global___TopicRuleAssetPropertyValue = TopicRuleAssetPropertyValue

@typing_extensions.final
class TopicRulePutAssetPropertyValueEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSET_ID_FIELD_NUMBER: builtins.int
    ENTRY_ID_FIELD_NUMBER: builtins.int
    PROPERTY_ALIAS_FIELD_NUMBER: builtins.int
    PROPERTY_ID_FIELD_NUMBER: builtins.int
    PROPERTY_VALUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    asset_id: builtins.str
    entry_id: builtins.str
    property_alias: builtins.str
    property_id: builtins.str
    @property
    def property_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicRuleAssetPropertyValue]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        asset_id: builtins.str = ...,
        entry_id: builtins.str = ...,
        property_alias: builtins.str = ...,
        property_id: builtins.str = ...,
        property_values: collections.abc.Iterable[global___TopicRuleAssetPropertyValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["asset_id", b"asset_id", "entry_id", b"entry_id", "property_alias", b"property_alias", "property_id", b"property_id", "property_values", b"property_values", "resource_info", b"resource_info"]) -> None: ...

global___TopicRulePutAssetPropertyValueEntry = TopicRulePutAssetPropertyValueEntry

@typing_extensions.final
class TopicRuleIotSiteWiseAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PUT_ASSET_PROPERTY_VALUE_ENTRIES_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def put_asset_property_value_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicRulePutAssetPropertyValueEntry]: ...
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        put_asset_property_value_entries: collections.abc.Iterable[global___TopicRulePutAssetPropertyValueEntry] | None = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["put_asset_property_value_entries", b"put_asset_property_value_entries", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleIotSiteWiseAction = TopicRuleIotSiteWiseAction

@typing_extensions.final
class TopicRuleKinesisAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARTITION_KEY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    partition_key: builtins.str
    role_arn: builtins.str
    stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        partition_key: builtins.str = ...,
        role_arn: builtins.str = ...,
        stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["partition_key", b"partition_key", "resource_info", b"resource_info", "role_arn", b"role_arn", "stream_name", b"stream_name"]) -> None: ...

global___TopicRuleKinesisAction = TopicRuleKinesisAction

@typing_extensions.final
class TopicRuleLambdaAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    function_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        function_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["function_arn", b"function_arn", "resource_info", b"resource_info"]) -> None: ...

global___TopicRuleLambdaAction = TopicRuleLambdaAction

@typing_extensions.final
class TopicRuleRepublishAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    QOS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    qos: builtins.int
    role_arn: builtins.str
    topic: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        qos: builtins.int = ...,
        role_arn: builtins.str = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["qos", b"qos", "resource_info", b"resource_info", "role_arn", b"role_arn", "topic", b"topic"]) -> None: ...

global___TopicRuleRepublishAction = TopicRuleRepublishAction

@typing_extensions.final
class TopicRuleS3Action(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_name: builtins.str
    key: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_name: builtins.str = ...,
        key: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "key", b"key", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___TopicRuleS3Action = TopicRuleS3Action

@typing_extensions.final
class TopicRuleSnsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MESSAGE_FORMAT_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    message_format: builtins.str
    role_arn: builtins.str
    target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        message_format: builtins.str = ...,
        role_arn: builtins.str = ...,
        target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_format", b"message_format", "resource_info", b"resource_info", "role_arn", b"role_arn", "target_arn", b"target_arn"]) -> None: ...

global___TopicRuleSnsAction = TopicRuleSnsAction

@typing_extensions.final
class TopicRuleSqsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    QUEUE_URL_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    USE_BASE64_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    queue_url: builtins.str
    role_arn: builtins.str
    use_base64: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        queue_url: builtins.str = ...,
        role_arn: builtins.str = ...,
        use_base64: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["queue_url", b"queue_url", "resource_info", b"resource_info", "role_arn", b"role_arn", "use_base64", b"use_base64"]) -> None: ...

global___TopicRuleSqsAction = TopicRuleSqsAction

@typing_extensions.final
class TopicRuleStepFunctionsAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EXECUTION_NAME_PREFIX_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    STATE_MACHINE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    execution_name_prefix: builtins.str
    role_arn: builtins.str
    state_machine_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        execution_name_prefix: builtins.str = ...,
        role_arn: builtins.str = ...,
        state_machine_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_name_prefix", b"execution_name_prefix", "resource_info", b"resource_info", "role_arn", b"role_arn", "state_machine_name", b"state_machine_name"]) -> None: ...

global___TopicRuleStepFunctionsAction = TopicRuleStepFunctionsAction

@typing_extensions.final
class TopicRuleAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUDWATCH_ALARM_FIELD_NUMBER: builtins.int
    CLOUDWATCH_METRIC_FIELD_NUMBER: builtins.int
    DYNAMO_DB_FIELD_NUMBER: builtins.int
    DYNAMO_DBV2_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_FIELD_NUMBER: builtins.int
    FIREHOSE_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    IOT_ANALYTICS_FIELD_NUMBER: builtins.int
    IOT_EVENTS_FIELD_NUMBER: builtins.int
    IOT_SITE_WISE_FIELD_NUMBER: builtins.int
    KINESIS_FIELD_NUMBER: builtins.int
    LAMBDA_FIELD_NUMBER: builtins.int
    REPUBLISH_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    SNS_FIELD_NUMBER: builtins.int
    SQS_FIELD_NUMBER: builtins.int
    STEP_FUNCTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloudwatch_alarm(self) -> global___TopicRuleCloudwatchAlarmAction: ...
    @property
    def cloudwatch_metric(self) -> global___TopicRuleCloudwatchMetricAction: ...
    @property
    def dynamo_db(self) -> global___TopicRuleDynamoDBAction: ...
    @property
    def dynamo_dbv2(self) -> global___TopicRuleDynamoDBv2Action: ...
    @property
    def elasticsearch(self) -> global___TopicRuleElasticsearchAction: ...
    @property
    def firehose(self) -> global___TopicRuleFirehoseAction: ...
    @property
    def http(self) -> global___TopicRuleHttpAction: ...
    @property
    def iot_analytics(self) -> global___TopicRuleIotAnalyticsAction: ...
    @property
    def iot_events(self) -> global___TopicRuleIotEventsAction: ...
    @property
    def iot_site_wise(self) -> global___TopicRuleIotSiteWiseAction: ...
    @property
    def kinesis(self) -> global___TopicRuleKinesisAction: ...
    @property
    def republish(self) -> global___TopicRuleRepublishAction: ...
    @property
    def s3(self) -> global___TopicRuleS3Action: ...
    @property
    def sns(self) -> global___TopicRuleSnsAction: ...
    @property
    def sqs(self) -> global___TopicRuleSqsAction: ...
    @property
    def step_functions(self) -> global___TopicRuleStepFunctionsAction: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloudwatch_alarm: global___TopicRuleCloudwatchAlarmAction | None = ...,
        cloudwatch_metric: global___TopicRuleCloudwatchMetricAction | None = ...,
        dynamo_db: global___TopicRuleDynamoDBAction | None = ...,
        dynamo_dbv2: global___TopicRuleDynamoDBv2Action | None = ...,
        elasticsearch: global___TopicRuleElasticsearchAction | None = ...,
        firehose: global___TopicRuleFirehoseAction | None = ...,
        http: global___TopicRuleHttpAction | None = ...,
        iot_analytics: global___TopicRuleIotAnalyticsAction | None = ...,
        iot_events: global___TopicRuleIotEventsAction | None = ...,
        iot_site_wise: global___TopicRuleIotSiteWiseAction | None = ...,
        kinesis: global___TopicRuleKinesisAction | None = ...,
        republish: global___TopicRuleRepublishAction | None = ...,
        s3: global___TopicRuleS3Action | None = ...,
        sns: global___TopicRuleSnsAction | None = ...,
        sqs: global___TopicRuleSqsAction | None = ...,
        step_functions: global___TopicRuleStepFunctionsAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloudwatch_alarm", b"cloudwatch_alarm", "cloudwatch_metric", b"cloudwatch_metric", "dynamo_db", b"dynamo_db", "dynamo_dbv2", b"dynamo_dbv2", "elasticsearch", b"elasticsearch", "firehose", b"firehose", "http", b"http", "iot_analytics", b"iot_analytics", "iot_events", b"iot_events", "iot_site_wise", b"iot_site_wise", "kinesis", b"kinesis", "lambda", b"lambda", "republish", b"republish", "resource_info", b"resource_info", "s3", b"s3", "sns", b"sns", "sqs", b"sqs", "step_functions", b"step_functions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloudwatch_alarm", b"cloudwatch_alarm", "cloudwatch_metric", b"cloudwatch_metric", "dynamo_db", b"dynamo_db", "dynamo_dbv2", b"dynamo_dbv2", "elasticsearch", b"elasticsearch", "firehose", b"firehose", "http", b"http", "iot_analytics", b"iot_analytics", "iot_events", b"iot_events", "iot_site_wise", b"iot_site_wise", "kinesis", b"kinesis", "lambda", b"lambda", "republish", b"republish", "resource_info", b"resource_info", "s3", b"s3", "sns", b"sns", "sqs", b"sqs", "step_functions", b"step_functions"]) -> None: ...

global___TopicRuleAction = TopicRuleAction

@typing_extensions.final
class TopicRuleTopicRulePayload(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    AWS_IOT_SQL_VERSION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERROR_ACTION_FIELD_NUMBER: builtins.int
    RULE_DISABLED_FIELD_NUMBER: builtins.int
    SQL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicRuleAction]: ...
    aws_iot_sql_version: builtins.str
    description: builtins.str
    @property
    def error_action(self) -> global___TopicRuleAction: ...
    rule_disabled: builtins.bool
    sql: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        actions: collections.abc.Iterable[global___TopicRuleAction] | None = ...,
        aws_iot_sql_version: builtins.str = ...,
        description: builtins.str = ...,
        error_action: global___TopicRuleAction | None = ...,
        rule_disabled: builtins.bool = ...,
        sql: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["error_action", b"error_action", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "aws_iot_sql_version", b"aws_iot_sql_version", "description", b"description", "error_action", b"error_action", "resource_info", b"resource_info", "rule_disabled", b"rule_disabled", "sql", b"sql"]) -> None: ...

global___TopicRuleTopicRulePayload = TopicRuleTopicRulePayload

@typing_extensions.final
class TopicRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RULE_NAME_FIELD_NUMBER: builtins.int
    TOPIC_RULE_PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    rule_name: builtins.str
    @property
    def topic_rule_payload(self) -> global___TopicRuleTopicRulePayload: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        rule_name: builtins.str = ...,
        topic_rule_payload: global___TopicRuleTopicRulePayload | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "topic_rule_payload", b"topic_rule_payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rule_name", b"rule_name", "topic_rule_payload", b"topic_rule_payload"]) -> None: ...

global___TopicRule = TopicRule
